@@ -309,7 +309,7 @@ class Ink(object):
         return [ink]
 
 
-class AspectRatio(object):
+class Aspect_ratio(object):
 
     normalize = True
 
